/*******************************************************************************
* This file is part of RaptorMenu.
*  Maintained by : Siraj Razick <siraj@kde.org> and Lukas Appelhans <l.appelhans@gmx.de>
*  Authored By  :
*
*  RaptorMenu is free software: you can redistribute it and/or modify
*  it under the terms of the GNU Lesser General Public License as published by
*  the Free Software Foundation, either version 3 of the License, or
*  (at your option) any later version.
*
*  RaptorMenu is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU Lesser General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with RaptorMenu. If not, see <http://www.gnu.org/licenses/lgpl.html>
*******************************************************************************/
#include "menuview.h"

#include "backdropplugin.h"
#include <userinterfaceplugin.h>
#include "pluginloader.h"

#include <QPainter>

namespace RaptorMenu
{
class MenuView::Private
{
    public:
        Private() {}
        UserInterfacePlugin * uiplugin;
        BackDropPlugin * bgplugin;
};

MenuView::MenuView(QGraphicsScene * scene, QWidget * parent)
  : QGraphicsView(scene,parent),
    d(new Private)
{
    ///setScene(new RaptorCanvas());
    setWindowFlags(Qt::FramelessWindowHint | Qt::Tool);
    setFrameStyle(QFrame::NoFrame);
    setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
    setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
    setViewportUpdateMode(QGraphicsView::SmartViewportUpdate);
    setAlignment(Qt::AlignLeft | Qt::AlignTop);      

    //Load default Plugins
    d->uiplugin = qobject_cast<UserInterfacePlugin*>(PluginLoader::instance()->pluginInstance("UserInterfacePlugin"));
    d->bgplugin = qobject_cast<BackDropPlugin*>(PluginLoader::instance()->pluginInstance("BackDropPlugin"));

    if (d->uiplugin) {
        if (d->uiplugin->graphicsWidget()) {
            this->scene()->addItem(d->uiplugin->graphicsWidget());
            d->uiplugin->graphicsWidget()->show();
        }
    }
}

MenuView::~MenuView()
{
    delete d;
}

void MenuView::backgroundChanged()
{
    invalidateScene();
    scene()->update();
}

void MenuView::drawBackground(QPainter * painter, const QRectF & rect)
{
    painter->setCompositionMode(QPainter::CompositionMode_Source);
    painter->fillRect(rect, Qt::transparent);
    painter->setCompositionMode(QPainter::CompositionMode_SourceOver);

    painter->save();
    painter->setClipRect(rect);
    if (d->bgplugin)
    {
	d->bgplugin->render(painter, rect);
    }
    painter->restore();
    
}
}

#include "menuview.moc"


 
