/*******************************************************************************
* This file is part of RaptorMenu.
*  Maintained by : Siraj Razick <siraj@kde.org>
*  Authored By  :
*
*  RaptorMenu is free software: you can redistribute it and/or modify
*  it under the terms of the GNU Lesser General Public License as published by
*  the Free Software Foundation, either version 3 of the License, or
*  (at your option) any later version.
*
*  RaptorMenu is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU Lesser General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with RaptorMenu. If not, see <http://www.gnu.org/licenses/lgpl.html>
*******************************************************************************/
#include "pluginloader.h"
#include <config-raptormenu.h>
//KDE headers
#include <KStandardDirs>
#include <KDebug>
#include <KService>
#include <KServiceTypeTrader>

namespace RaptorMenu
{
PluginLoader * PluginLoader::m_Instance = 0;

class PluginLoader::Private
{
public:
    Private() {}
    ~Private() {}
    PluginMap map;
};

PluginLoader::PluginLoader ()
  :d (new Private)
{
    load("DataPlugin");
    load("UserInterfacePlugin");
    load("BackDropPlugin");
}

PluginLoader::~PluginLoader ()
{
    delete d;
}

PluginLoader * PluginLoader::instance()
{
    if (!m_Instance) {
        m_Instance = new PluginLoader();
    }

    return m_Instance;
}

Plugin * PluginLoader::loadDefault(PluginType type)
{
    if (type == Menu) {}
    else if (type == Data) {}
    else if (type == BackDrop) {}
    return 0;
}

Plugin * PluginLoader::pluginInstance(const QString& name)
{
    if (d->map[name]) {
        return d->map[name];
    }

    return 0;
}

void PluginLoader::load(const QString& name)
{
    QStringList pluginList;
    KService::List offers = KServiceTypeTrader::self()->query("Raptormenu/" + name);
    Plugin * pluginPtr = 0;
    QString error;
    foreach (KService::Ptr service , offers) {
        QVariantList args;
        args << service->storageId() << "";
        pluginPtr = KService::createInstance<Plugin>(service, 0,args,&error);
        kDebug() << pluginPtr<<endl; 
        if (pluginPtr) {
            d->map[name] = pluginPtr;
        }else {
            kDebug()<<"Error Loading Plugin"<<name<<endl;
        }
    }
 }
}

#include "pluginloader.moc"
