/*
*   Copyright (C) 2006
*   Siraj Razick <siraj@kdemail.net>
*   PhobosK <phobosk@mail.kbfx.org>
*   Lahiru Lakmal <llahiru@gmail.com>
*   Lukas Appelhans <l.appelhans@gmx.de>
*   see Also AUTHORS
*
*   This program is free software; you can redistribute it and/or modify
*   it under the terms of the GNU Library General Public License version 2 as
*   published by the Free Software Foundation
*
*   This program is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*   GNU General Public License for more details
*
*   You should have received a copy of the GNU Library General Public
*   License along with this program; if not, write to the
*   Free Software Foundation, Inc.,
*   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/
#include "taskgroup.h"

#include <QDebug>

namespace Tom
{
TaskGroup::TaskGroup(QObject *parent)
  : AbstractItem(parent)
{
}

TaskGroup::~TaskGroup()
{
}

void TaskGroup::addItem(TaskItem *item)
{
    item->setParent(this);
    m_taskItems.append(item);
}

void TaskGroup::addGroup(TaskGroup *group)
{
    group->setParent(this);
    m_taskGroups.append(group);
}

QList<AbstractItem*> TaskGroup::children()
{
    QList<AbstractItem*> children;
    foreach (TaskGroup *group, m_taskGroups)
        children << qobject_cast<AbstractItem*>(group);
    foreach (TaskItem *item, m_taskItems)
        children << qobject_cast<AbstractItem*>(item);
    return children;
}

void TaskGroup::save(const QDomElement &e)
{
    QDomElement element = e;
    foreach (TaskGroup *group, m_taskGroups)
    {
        QDomElement t = element.ownerDocument().createElement("TaskGroup");
        element.appendChild(t);
        group->save(t);
    }
    foreach (TaskItem *item, m_taskItems)
    {
        QDomElement t = element.ownerDocument().createElement("TaskItem");
        element.appendChild(t);
        item->save(t);
    }
    AbstractItem::save(e);
}

void TaskGroup::load(const QDomElement &e)
{
    QDomNodeList groups = e.elementsByTagName("TaskGroup");
    for (int i = 0; i != groups.count(); i++)
    {
        TaskGroup *group = new TaskGroup(this);
        group->load(groups.at(i).toElement());
        m_taskGroups.append(group);
    }
    QDomNodeList items = e.elementsByTagName("TaskItem");
    for (int i = 0; i != items.count(); i++)
    {
        TaskItem *item = new TaskItem(this);
        item->load(items.at(i).toElement());
        qDebug() << "Load item " + item->name();
        m_taskItems.append(item);
    }
    AbstractItem::load(e);
}
}
