/* This file is part of the KDE project

   Copyright (C) 2008 Lukas Appelhans <l.appelhans@gmx.de>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
*/ 
#include "tomedit.h"

#include "tomeditmodel.h"

#include <RaptorTom>
#include <QHeaderView>
#include <QFile>
#include <QTextStream>
#include <QCloseEvent>

#include <KIcon>
#include <KStandardDirs>
#include <KDebug>

TomEdit::TomEdit(QWidget *parent)
  : QMainWindow(parent),
    m_doc(0)
{
    setupUi(this);
    m_tom = new Tom::Tom(this);
    Tom::TaskGroup *group = new Tom::TaskGroup(m_tom);
    group->setName("Bla");
    group->setIconName("list-add");
    group->setDescription("bla bla blub");
    group->setLongDescription("bla bla blub and more and long^^");
    Tom::TaskGroup *second = new Tom::TaskGroup(group);
    second->setName("haha");
    group->addGroup(second);
    Tom::TaskItem *item = new Tom::TaskItem(group);
    item->setName("blub");
    item->setIconName("list-add");
    second->addItem(item);
    m_tom->addTaskGroup(group);
    QFile file(KStandardDirs::locateLocal("appdata", "tom.xml"));
    if (!file.open(QIODevice::ReadOnly))
    {
        kDebug() << "Cannot open file";
        return;
    }
    m_doc = new QDomDocument("TomXML");
    if(m_doc->setContent(&file))
        m_tom->load(m_doc);
    else
        kDebug() << "Cannot set content to DomDocument";
    file.close();
    m_model = new TomEditModel(m_tom, this);
    tomTreeView->setModel(m_model);
    setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
    setIconSize(QSize(48, 48));
    actionAdd_Menu->setIcon(KIcon("menu-add"));
    actionDelete_Menu->setIcon(KIcon("menu-delete"));
    actionAdd_Application->setIcon(KIcon("application-add"));
    actionDelete_Application->setIcon(KIcon("application-delete"));
    connect(closeButton, SIGNAL(clicked()), SLOT(close()));
    connect(actionAdd_Menu, SIGNAL(triggered()), SLOT(addMenu()));
    connect(actionDelete_Menu, SIGNAL(triggered()), SLOT(deleteMenu()));
    connect(actionAdd_Application, SIGNAL(triggered()), SLOT(addApplication()));
    connect(actionDelete_Application, SIGNAL(triggered()), SLOT(deleteApplication()));
    connect(tomTreeView->selectionModel(), SIGNAL(currentRowChanged(const QModelIndex &, const QModelIndex &)), SLOT(itemChanged(const QModelIndex &)));
    connect(this, SIGNAL(destroyed(QObject*)), SLOT(save()));
}

TomEdit::~TomEdit()
{
    if (m_tom) {
        delete m_tom;
    }
}

void TomEdit::closeEvent(QCloseEvent *event)
{
    Q_UNUSED(event)
    save();//TODO: Better sollution
}

void TomEdit::save()
{
    QFile::remove(KStandardDirs::locateLocal("appdata", "tom.xml"));
    kDebug() << "Called";
    if (!m_doc)
        m_doc = new QDomDocument("TomXML");

    QFile file(KStandardDirs::locateLocal("appdata", "tom.xml"));
    if (!file.open(QIODevice::WriteOnly))
    {
        kDebug() << "Cannot open file";
        return;
    }

    if (m_tom)
        m_tom->save(m_doc);

    QTextStream stream(&file);
    m_doc->save(stream, 0);
    file.close();
    delete m_doc;
}

void TomEdit::addMenu()
{
}

void TomEdit::deleteMenu()
{
}

void TomEdit::addApplication()
{
}

void TomEdit::deleteApplication()
{
}

void TomEdit::itemChanged(const QModelIndex &i)
{
    Tom::AbstractItem *item = m_model->itemForModelIndex(i);
    if (!item)
        return;
    //TODO: Instead of iconLabel use a KIconButton
    nameLine->setText(item->name());
    iconLabel->setPixmap(KIcon(item->iconName()).pixmap(96, 96));
    if (!item->isGroup())
    {
        Tom::TaskItem *task = static_cast<Tom::TaskItem*>(item);
        pathLine->setText(task->program());
        connect(pathLine, SIGNAL(textChanged(const QString &)), task, SLOT(setProgram(const QString &)));
    }
    else
    {
        pathLine->setDisabled(true);
        pathLabel->setDisabled(true);
    }
    descriptionEdit->setText(item->description());
    longDescriptionEdit->setText(item->longDescription());
    connect(nameLine, SIGNAL(textChanged(const QString &)), item, SLOT(setName(const QString &)));
}
