/* This file is part of the KDE project

   Copyright (C) 2008 Lukas Appelhans <l.appelhans@gmx.de>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
*/ 

#include "tomeditmodel.h"

#include <KIcon>
#include <KDebug>
#include <RaptorTom>

TomEditModel::TomEditModel(Tom::Tom * tom, QObject *parent)
  : QAbstractItemModel(parent),
    m_tom(tom)
{
}

TomEditModel::~TomEditModel()
{
}

QVariant TomEditModel::data(const QModelIndex &index, int role) const
{
    Tom::AbstractItem *item = static_cast<Tom::AbstractItem*>(index.internalPointer());
    if (role == Qt::DisplayRole)
        return item->name();
    if (role == Qt::DecorationRole)
        return KIcon(item->iconName());
    return QVariant();
}

Qt::ItemFlags TomEditModel::flags(const QModelIndex &index) const
{
    Q_UNUSED(index);
    Qt::ItemFlags flags;
    flags |= Qt::ItemIsSelectable;
    flags |= Qt::ItemIsEnabled;
    return flags;
}

QModelIndex TomEditModel::index(int row, int column, const QModelIndex &parent) const
{
    if (row > rowCount(parent) || row < 0)
        return QModelIndex();
    if (!parent.isValid())
        return createIndex(row, column, m_tom->taskGroups().at(row));

    Tom::AbstractItem *item = static_cast<Tom::AbstractItem*>(parent.internalPointer());
    if (item->isGroup()) {
        return createIndex(row, column, qobject_cast<Tom::TaskGroup*>(item)->children().at(row));
    }

    return QModelIndex();
}

QModelIndex TomEditModel::parent(const QModelIndex &index) const
{
    if (!index.isValid())
         return QModelIndex();

    Tom::AbstractItem *item = static_cast<Tom::AbstractItem*>(index.internalPointer());
    if (!m_tom->taskGroups().contains(qobject_cast<Tom::TaskGroup*>(item)))
    {
        Tom::TaskGroup *parentItem = qobject_cast<Tom::TaskGroup*>(item->parent());
        if (m_tom->taskGroups().contains(parentItem))
            return createIndex(m_tom->taskGroups().indexOf(parentItem), 0, parentItem);
        else
            return createIndex(qobject_cast<Tom::TaskGroup*>(parentItem->parent())->children().count(), 0, parentItem);
    }
    return QModelIndex();
}

int TomEditModel::rowCount(const QModelIndex &parent) const
{
    if (!parent.isValid())
    {
        if (m_tom->taskGroups().isEmpty())
            return 0;
        return m_tom->taskGroups().count();
    }

    Tom::AbstractItem *item = static_cast<Tom::AbstractItem*>(parent.internalPointer());
    if (item && item->isGroup()) {
    	Tom::TaskGroup *group = qobject_cast<Tom::TaskGroup*>(item);
    	if(group)
    		return group->children().count();
    }

    return 0;
}

int TomEditModel::columnCount(const QModelIndex &parent) const
{
    Q_UNUSED(parent);
    return 1;
}

Tom::AbstractItem * TomEditModel::itemForModelIndex(const QModelIndex &index)
{
    return static_cast<Tom::AbstractItem*>(index.internalPointer());
}
