/*******************************************************************************
* This file is part of PlexyDesk.
*  Maintained by : Siraj Razick <siraj@kde.org>
*  Authored By  :
*
*  PlexyDesk is free software: you can redistribute it and/or modify
*  it under the terms of the GNU Lesser General Public License as published by
*  the Free Software Foundation, either version 3 of the License, or
*  (at your option) any later version.
*
*  PlexyDesk is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU Lesser General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with PlexyDesk. If not, see <http://www.gnu.org/licenses/lgpl.html>
*******************************************************************************/
#include "bghelper.h"
#include <config-raptormenu.h>
#include <QSvgRenderer>

const QString BACKGROUND        = "/share/apps/desktoptheme/default/raptor-menu/";

BgHelper::BgHelper(QObject * object) : Plugin( object)
{
    m_bgImage = NULL;
}

BgHelper::~BgHelper()
{
}

void BgHelper::renderPanel(QPainter *p, QRectF r, QString filename)
{
    if(m_backgroundRect != r)
    {
        m_filename = filename;
        m_backgroundRect = r;
        updateBackground(p);
    }
}

void BgHelper::updateBackground(QPainter* p)
{
    if(!m_bgImage)
    {
        m_bgImage = new QSvgRenderer(RAPTORPREFIX + BACKGROUND + m_filename, this);
    }

    for(side_map_type::iterator i = side_map().begin(); i != side_map().end(); i++)
    {
        QRectF elementRect = m_bgImage->boundsOnElement(i->second);             //Get original SVG coords

        if (i->first==TOP_RIGHT || i->first==RIGHT || i->first==BOTTOM_RIGHT)   //Right hand side elements align right
        {
            elementRect.moveRight(m_backgroundRect.right() + m_backgroundRect.x());
        }

        if (i->first==BOTTOM_LEFT || i->first==BOTTOM || i->first==BOTTOM_RIGHT)    //Bottom elements align bottom
        {
            elementRect.moveBottom(m_backgroundRect.bottom() + m_backgroundRect.y());
        }

        if (i->first==TOP || i->first==BOTTOM || i->first==CENTER)              //Stretch centre vertical elements on x
        {
            elementRect.setWidth(m_backgroundRect.right() + m_backgroundRect.x() - 2 * elementRect.x());
        }
        if (i->first==LEFT || i->first==RIGHT || i->first==CENTER)              //Stretch centre horizontal elements on y
        {
            elementRect.setHeight(m_backgroundRect.bottom() + m_backgroundRect.y() - 2 * elementRect.y());
        }

        m_bgImage->render(p, i->second, elementRect);
    }
}

#include "bghelper.moc"


