/*******************************************************************************
* This file is part of RaptorMenu.
*  Maintained by : Siraj Razick <siraj@kde.org>
*  Authored By  :
*
*  RaptorMenu is free software: you can redistribute it and/or modify
*  it under the terms of the GNU Lesser General Public License as published by
*  the Free Software Foundation, either version 3 of the License, or
*  (at your option) any later version.
*
*  RaptorMenu is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU Lesser General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with RaptorMenu. If not, see <http://www.gnu.org/licenses/lgpl.html>
*******************************************************************************/
#ifndef RAPTOR_CLASSIC_BGHELPER_H
#define RAPTOR_CLASSIC_BGHELPER_H

#include <raptor_exports.h>
#include <config-raptormenu.h>
#include <plugin.h>
#include <QPixmap>
#include <QRectF>
#include <map>

class QSvgRenderer;

class RAPTOR_EXPORT BgHelper : public RaptorMenu::Plugin
{
    Q_OBJECT

public:
    enum Side
    {
        TOP_LEFT,
        TOP,
        TOP_RIGHT,
        LEFT,
        CENTER,
        RIGHT,
        BOTTOM_LEFT,
        BOTTOM,
        BOTTOM_RIGHT
    };
    BgHelper(QObject * object = 0);
    virtual ~BgHelper();
    void renderPanel(QPainter *p,QRectF r, QString filename);

private:
    void updateBackground(QPainter* p);

    QRectF m_backgroundRect;
    QSvgRenderer *m_bgImage;
    QPixmap m_bg;
    QString m_filename;

    typedef std::map<Side, const QString> side_map_type;

    side_map_type& side_map()
    {
        const side_map_type::value_type side_map_init[]=
        {
            std::make_pair(TOP_LEFT, QString("topleft")),
            std::make_pair(TOP, QString("top")),
            std::make_pair(TOP_RIGHT, QString("topright")),
            std::make_pair(LEFT, QString("left")),
            std::make_pair(CENTER, QString("center")),
            std::make_pair(RIGHT, QString("right")),
            std::make_pair(BOTTOM_LEFT, QString("bottomleft")),
            std::make_pair(BOTTOM, QString("bottom")),
            std::make_pair(BOTTOM_RIGHT, QString("bottomright")),
        };

        static side_map_type side_map_static(side_map_init, 
            side_map_init + sizeof(side_map_init)/sizeof(side_map_init[0]));

        return side_map_static;
    }
};

#endif //RAPTOR_CLASSIC_BGHELPER_H
